@@ -48,6 +48,13 @@ class StringUtilsTest {
                 '\u000B',
                 '\f',
                 '\r',
+                /*
+                 Misses four characters (from Unicode category "B"):
+                    - FS (File Separator): Code point 28 (0x1C), used to separate files.
+                    - GS (Group Separator): Code point 29 (0x1D), used to separate groups of records.
+                    - RS (Record Separator): Code point 30 (0x1E), used to separate records within a file.
+                    - US (Unit Separator): Code point 31 (0x1F), used to separate units of data or fields.
+                */
                 ' ',
                 '\u0085',
                 '\u00A0',
@@ -75,4 +82,11 @@ class StringUtilsTest {
         }
     }
 
+    @Test
+    void isWhitespace_contains_all_whitespaces_and_no_non_whitespace_chars() {
+        for (char c = Character.MIN_VALUE; c < Character.MAX_VALUE; c++) {
+            assertEquals(StringUtils.isWhiteSpaceSlow(c), StringUtils.isWhitespace(c),
+                    "Mismatch for char " + (int) c + " '" + c + "'");
+        }
+    }
 }
